﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.RazorPages;
using EF_ServerSide_Paging_Razor_Core.Models;

namespace EF_ServerSide_Paging_Razor_Core.Pages
{
    public class IndexModel : PageModel
    {
        private DBCtx Context { get; }
        public IndexModel(DBCtx _context)
        {
            this.Context = _context;
        }

        public CustomerModel CustomerModel { get; set; }

        public void OnGet()
        {
            this.CustomerModel = this.GetCustomers(1);
        }

        public void OnPostSubmit(int currentPageIndex)
        {
            this.CustomerModel = this.GetCustomers(currentPageIndex);
        }

        private CustomerModel GetCustomers(int currentPage)
        {
            int maxRows = 10;
            CustomerModel customerModel = new CustomerModel();

            customerModel.Customers = (from customer in this.Context.Customers
                                       select customer)
                        .OrderBy(customer => customer.CustomerID)
                        .Skip((currentPage - 1) * maxRows)
                        .Take(maxRows).ToList();

            double pageCount = (double)((decimal)this.Context.Customers.Count() / Convert.ToDecimal(maxRows));
            customerModel.PageCount = (int)Math.Ceiling(pageCount);

            customerModel.CurrentPageIndex = currentPage;

            return customerModel;
        }
    }
}